# coding: utf-8

"""
    DeviceServer

    DeviceServer API

    The version of the OpenAPI document: 1.2.2
    Contact: david@3adesign.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from DeviceServer.api.device_mount_system_api import DeviceMountSystemApi


class TestDeviceMountSystemApi(unittest.TestCase):
    """DeviceMountSystemApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DeviceMountSystemApi()

    def tearDown(self) -> None:
        pass

    def test_get_tray_description(self) -> None:
        """Test case for get_tray_description

        GET description of Tray
        """
        pass

    def test_get_tray_present(self) -> None:
        """Test case for get_tray_present

        GET state of Port Module Relay
        """
        pass

    def test_get_tray_uuid(self) -> None:
        """Test case for get_tray_uuid

        GET UUID of Tray
        """
        pass

    def test_put_tray_description(self) -> None:
        """Test case for put_tray_description

        PUT description of Tray
        """
        pass

    def test_put_tray_uuid(self) -> None:
        """Test case for put_tray_uuid

        PUT UUID of Tray
        """
        pass


if __name__ == '__main__':
    unittest.main()
