# coding: utf-8

"""
    DeviceServer

    DeviceServer API

    The version of the OpenAPI document: 1.2.2
    Contact: david@3adesign.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from DeviceServer.api.devices_api import DevicesApi


class TestDevicesApi(unittest.TestCase):
    """DevicesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DevicesApi()

    def tearDown(self) -> None:
        pass

    def test_get_current(self) -> None:
        """Test case for get_current

        GET current reading of device
        """
        pass

    def test_get_device_device_id_buttons(self) -> None:
        """Test case for get_device_device_id_buttons

        GET all buttons for device
        """
        pass

    def test_get_device_device_id_leds(self) -> None:
        """Test case for get_device_device_id_leds

        GET all leds for Device
        """
        pass

    def test_get_device_device_id_ports(self) -> None:
        """Test case for get_device_device_id_ports

        GET all Ports for Device
        """
        pass

    def test_get_device_device_id_temperature_ports(self) -> None:
        """Test case for get_device_device_id_temperature_ports

        GET all temperature ports for device
        """
        pass

    def test_get_device_id_port_index(self) -> None:
        """Test case for get_device_id_port_index

        GET status of port
        """
        pass

    def test_get_device_port_current(self) -> None:
        """Test case for get_device_port_current

        GET current reading of device Port
        """
        pass

    def test_get_device_port_module_led_state(self) -> None:
        """Test case for get_device_port_module_led_state

        GET state of Port Module Led
        """
        pass

    def test_get_device_port_module_relay_state(self) -> None:
        """Test case for get_device_port_module_relay_state

        GET state of Port Module Relay
        """
        pass

    def test_get_device_port_voltage(self) -> None:
        """Test case for get_device_port_voltage

        GET voltage reading of device Port
        """
        pass

    def test_get_device_rotation_angle(self) -> None:
        """Test case for get_device_rotation_angle

        GET Rotation Angle
        """
        pass

    def test_get_device_rotation_speed(self) -> None:
        """Test case for get_device_rotation_speed

        GET Turntable Speed
        """
        pass

    def test_get_device_uuid_deprecated(self) -> None:
        """Test case for get_device_uuid_deprecated

        GET uuid from database
        """
        pass

    def test_get_devices(self) -> None:
        """Test case for get_devices

        GET list of devices
        """
        pass

    def test_get_devices_button(self) -> None:
        """Test case for get_devices_button

        GET status of button
        """
        pass

    def test_get_devices_index(self) -> None:
        """Test case for get_devices_index

        GET single device
        """
        pass

    def test_get_devices_led(self) -> None:
        """Test case for get_devices_led

        GET status of Led
        """
        pass

    def test_get_devices_temperature(self) -> None:
        """Test case for get_devices_temperature

        GET temperature reading
        """
        pass

    def test_get_fan_speed(self) -> None:
        """Test case for get_fan_speed

        GET device fan speed
        """
        pass

    def test_get_fan_target_temperature(self) -> None:
        """Test case for get_fan_target_temperature

        GET device fan target temperature
        """
        pass

    def test_get_fan_temperature(self) -> None:
        """Test case for get_fan_temperature

        GET device fan temperature
        """
        pass

    def test_get_firmware_version(self) -> None:
        """Test case for get_firmware_version

        GET Device Firmware Version
        """
        pass

    def test_get_image(self) -> None:
        """Test case for get_image

        GET Image
        """
        pass

    def test_get_image_names(self) -> None:
        """Test case for get_image_names

        GET Image Names
        """
        pass

    def test_get_message_from_rx_buffer_deprecated(self) -> None:
        """Test case for get_message_from_rx_buffer_deprecated

        GET message from RX table
        """
        pass

    def test_get_message_from_tx_buffer_deprecated(self) -> None:
        """Test case for get_message_from_tx_buffer_deprecated

        GET message from TX table
        """
        pass

    def test_get_port(self) -> None:
        """Test case for get_port

        GET status of Port by id
        """
        pass

    def test_get_port_led_state(self) -> None:
        """Test case for get_port_led_state

        GET state of Port LED
        """
        pass

    def test_get_port_setup_status(self) -> None:
        """Test case for get_port_setup_status

        GET setup status of Port
        """
        pass

    def test_get_port_states(self) -> None:
        """Test case for get_port_states

        GET port states by Port id
        """
        pass

    def test_get_ports(self) -> None:
        """Test case for get_ports

        GET status of all ports
        """
        pass

    def test_get_relay_state(self) -> None:
        """Test case for get_relay_state

        GET state of relay
        """
        pass

    def test_get_temperature_range(self) -> None:
        """Test case for get_temperature_range

        GET Temperature Range
        """
        pass

    def test_get_temperature_thresholds(self) -> None:
        """Test case for get_temperature_thresholds

        GET Temperature Thresholds
        """
        pass

    def test_get_turntable_calibration_data(self) -> None:
        """Test case for get_turntable_calibration_data

        GET Turntable Calibration Values
        """
        pass

    def test_get_voltage(self) -> None:
        """Test case for get_voltage

        GET voltage reading of device
        """
        pass

    def test_put_auto_calibrate_turntable(self) -> None:
        """Test case for put_auto_calibrate_turntable

        PUT Calibration
        """
        pass

    def test_put_device_deprecated(self) -> None:
        """Test case for put_device_deprecated

        PUT Add evice
        """
        pass

    def test_put_device_device_id_description(self) -> None:
        """Test case for put_device_device_id_description

        PUT a description for a Device
        """
        pass

    def test_put_device_device_id_name(self) -> None:
        """Test case for put_device_device_id_name

        PUT a name for a Device
        """
        pass

    def test_put_device_id_label(self) -> None:
        """Test case for put_device_id_label

        PUT a Port label
        """
        pass

    def test_put_device_port_module_led_state(self) -> None:
        """Test case for put_device_port_module_led_state

        PUT state of Port Module LED
        """
        pass

    def test_put_device_port_module_relay_state(self) -> None:
        """Test case for put_device_port_module_relay_state

        PUT state of Port Module Relay
        """
        pass

    def test_put_device_rotation_angle(self) -> None:
        """Test case for put_device_rotation_angle

        PUT Rotation
        """
        pass

    def test_put_device_rotation_angle_continuous(self) -> None:
        """Test case for put_device_rotation_angle_continuous

        PUT Continious Rotation
        """
        pass

    def test_put_device_rotation_speed(self) -> None:
        """Test case for put_device_rotation_speed

        PUT Turntable Speed
        """
        pass

    def test_put_devices_led_index(self) -> None:
        """Test case for put_devices_led_index

        PUT state of Led
        """
        pass

    def test_put_devices_ports(self) -> None:
        """Test case for put_devices_ports

        PUT state of port
        """
        pass

    def test_put_halt_rotation(self) -> None:
        """Test case for put_halt_rotation

        PUT Halt Rotation
        """
        pass

    def test_put_port_led_state(self) -> None:
        """Test case for put_port_led_state

        PUT state of Port LED
        """
        pass

    def test_put_port_port_id_label(self) -> None:
        """Test case for put_port_port_id_label

        PUT the label for a Port
        """
        pass

    def test_put_port_port_id_state_label(self) -> None:
        """Test case for put_port_port_id_state_label

        PUT state label
        """
        pass

    def test_put_ports_pulse(self) -> None:
        """Test case for put_ports_pulse

        PUT Port into state for period of time
        """
        pass

    def test_put_relay_state(self) -> None:
        """Test case for put_relay_state

        PUT state of Relay
        """
        pass

    def test_put_serial_test_message_deprecated(self) -> None:
        """Test case for put_serial_test_message_deprecated

        Serial Message Test
        """
        pass

    def test_put_state_by_port_id(self) -> None:
        """Test case for put_state_by_port_id

        PUT state of port
        """
        pass


if __name__ == '__main__':
    unittest.main()
