# coding: utf-8

"""
    DeviceServer

    DeviceServer API

    The version of the OpenAPI document: 1.2.2
    Contact: david@3adesign.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from DeviceServer.models.db_button_state import DbButtonState

class TestDbButtonState(unittest.TestCase):
    """DbButtonState unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DbButtonState:
        """Test DbButtonState
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DbButtonState`
        """
        model = DbButtonState()
        if include_optional:
            return DbButtonState(
                button_state_id = '',
                button_id = '',
                label = '',
                index = 1
            )
        else:
            return DbButtonState(
                button_state_id = '',
                button_id = '',
                label = '',
                index = 1,
        )
        """

    def testDbButtonState(self):
        """Test DbButtonState"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
