# coding: utf-8

"""
    DeviceServer

    DeviceServer API

    The version of the OpenAPI document: 1.2.2
    Contact: david@3adesign.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from DeviceServer.models.db_device_port import DbDevicePort

class TestDbDevicePort(unittest.TestCase):
    """DbDevicePort unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DbDevicePort:
        """Test DbDevicePort
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DbDevicePort`
        """
        model = DbDevicePort()
        if include_optional:
            return DbDevicePort(
                port_id = '',
                port_index = 1,
                device_id = 'bf325375-e030-4fcc-aa00-917317c5747701234567891011121314151617181920212223242526272829303132333435',
                label = '',
                state_index = 0
            )
        else:
            return DbDevicePort(
                port_id = '',
                port_index = 1,
                device_id = 'bf325375-e030-4fcc-aa00-917317c5747701234567891011121314151617181920212223242526272829303132333435',
        )
        """

    def testDbDevicePort(self):
        """Test DbDevicePort"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
