# coding: utf-8

"""
    DeviceServer

    DeviceServer API

    The version of the OpenAPI document: 1.2.2
    Contact: david@3adesign.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from DeviceServer.api.attenuator_api import AttenuatorApi


class TestAttenuatorApi(unittest.TestCase):
    """AttenuatorApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AttenuatorApi()

    def tearDown(self) -> None:
        pass

    def test_get_attenuator_state(self) -> None:
        """Test case for get_attenuator_state

        GET attenuation state
        """
        pass

    def test_get_channel_attenuation(self) -> None:
        """Test case for get_channel_attenuation

        GET attenuation channel state
        """
        pass

    def test_get_device_attenuation_configuration(self) -> None:
        """Test case for get_device_attenuation_configuration

        GET attenuation device config
        """
        pass

    def test_put_attenuator_state(self) -> None:
        """Test case for put_attenuator_state

        PUT attenuation state
        """
        pass

    def test_put_channel_attenuation(self) -> None:
        """Test case for put_channel_attenuation

        PUT attenuation state
        """
        pass


if __name__ == '__main__':
    unittest.main()
