# coding: utf-8

"""
    DeviceServer

    DeviceServer API

    The version of the OpenAPI document: 1.2.2
    Contact: david@3adesign.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from DeviceServer.models.post_verify_user_access_request import PostVerifyUserAccessRequest

class TestPostVerifyUserAccessRequest(unittest.TestCase):
    """PostVerifyUserAccessRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PostVerifyUserAccessRequest:
        """Test PostVerifyUserAccessRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PostVerifyUserAccessRequest`
        """
        model = PostVerifyUserAccessRequest()
        if include_optional:
            return PostVerifyUserAccessRequest(
                acc = 56,
                clientid = '',
                topic = ''
            )
        else:
            return PostVerifyUserAccessRequest(
                acc = 56,
                clientid = '',
                topic = '',
        )
        """

    def testPostVerifyUserAccessRequest(self):
        """Test PostVerifyUserAccessRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
