# coding: utf-8

"""
    DeviceServer

    DeviceServer API

    The version of the OpenAPI document: 1.2.2
    Contact: david@3adesign.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from DeviceServer.api.serial_mux_api import SerialMuxApi


class TestSerialMuxApi(unittest.TestCase):
    """SerialMuxApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SerialMuxApi()

    def tearDown(self) -> None:
        pass

    def test_put_serial_test_message(self) -> None:
        """Test case for put_serial_test_message

        Serial Message Test
        """
        pass


if __name__ == '__main__':
    unittest.main()
