# coding: utf-8

"""
    DeviceServer

    DeviceServer API

    The version of the OpenAPI document: 1.2.2
    Contact: david@3adesign.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from DeviceServer.api.turntable_api import TurntableApi


class TestTurntableApi(unittest.TestCase):
    """TurntableApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TurntableApi()

    def tearDown(self) -> None:
        pass

    def test_turntable_get_device_rotation_angle(self) -> None:
        """Test case for turntable_get_device_rotation_angle

        GET Rotation Angle
        """
        pass

    def test_turntable_get_device_rotation_speed(self) -> None:
        """Test case for turntable_get_device_rotation_speed

        GET Turntable Speed
        """
        pass

    def test_turntable_get_image(self) -> None:
        """Test case for turntable_get_image

        GET Image
        """
        pass

    def test_turntable_get_image_names(self) -> None:
        """Test case for turntable_get_image_names

        GET Image Names
        """
        pass

    def test_turntable_get_turntable_calibration_data(self) -> None:
        """Test case for turntable_get_turntable_calibration_data

        GET Turntable Calibration Values
        """
        pass

    def test_turntable_put_auto_calibrate_turntable(self) -> None:
        """Test case for turntable_put_auto_calibrate_turntable

        PUT Calibration
        """
        pass

    def test_turntable_put_device_rotation_angle(self) -> None:
        """Test case for turntable_put_device_rotation_angle

        PUT Rotation
        """
        pass

    def test_turntable_put_device_rotation_angle_continuous(self) -> None:
        """Test case for turntable_put_device_rotation_angle_continuous

        PUT Continious Rotation
        """
        pass

    def test_turntable_put_device_rotation_speed(self) -> None:
        """Test case for turntable_put_device_rotation_speed

        PUT Turntable Speed
        """
        pass

    def test_turntable_put_halt_rotation(self) -> None:
        """Test case for turntable_put_halt_rotation

        PUT Halt Rotation
        """
        pass


if __name__ == '__main__':
    unittest.main()
