# coding: utf-8

"""
    DeviceServer

    DeviceServer API

    The version of the OpenAPI document: 1.2.2
    Contact: david@3adesign.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from DeviceServer.api.internal_api import InternalApi


class TestInternalApi(unittest.TestCase):
    """InternalApi unit test stubs"""

    def setUp(self) -> None:
        self.api = InternalApi()

    def tearDown(self) -> None:
        pass

    def test_get_device_uuid(self) -> None:
        """Test case for get_device_uuid

        GET uuid from database
        """
        pass

    def test_get_message_from_rx_buffer(self) -> None:
        """Test case for get_message_from_rx_buffer

        GET message from RX table
        """
        pass

    def test_get_message_from_tx_buffer(self) -> None:
        """Test case for get_message_from_tx_buffer

        GET message from TX table
        """
        pass

    def test_post_verify_jwt(self) -> None:
        """Test case for post_verify_jwt

        POST /verify_jwt
        """
        pass

    def test_post_verify_user_access(self) -> None:
        """Test case for post_verify_user_access

        POST /access_control
        """
        pass

    def test_put_device(self) -> None:
        """Test case for put_device

        PUT Add Device
        """
        pass


if __name__ == '__main__':
    unittest.main()
