# coding: utf-8

"""
    DeviceServer

    DeviceServer API

    The version of the OpenAPI document: 1.2.2
    Contact: david@3adesign.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from DeviceServer.models.device_rx_buffer import DeviceRxBuffer

class TestDeviceRxBuffer(unittest.TestCase):
    """DeviceRxBuffer unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DeviceRxBuffer:
        """Test DeviceRxBuffer
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DeviceRxBuffer`
        """
        model = DeviceRxBuffer()
        if include_optional:
            return DeviceRxBuffer(
                locator = '',
                state = '',
                timestamp_db_write = 56,
                timestamp_hid_message = 56
            )
        else:
            return DeviceRxBuffer(
                locator = '',
        )
        """

    def testDeviceRxBuffer(self):
        """Test DeviceRxBuffer"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
