# coding: utf-8

"""
    DeviceServer

    DeviceServer API

    The version of the OpenAPI document: 1.2.2
    Contact: david@3adesign.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from DeviceServer.api.docker_api import DockerApi


class TestDockerApi(unittest.TestCase):
    """DockerApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DockerApi()

    def tearDown(self) -> None:
        pass

    def test_get_container_logs(self) -> None:
        """Test case for get_container_logs

        GET a Docker container's logs
        """
        pass

    def test_get_docker_container_names(self) -> None:
        """Test case for get_docker_container_names

        GET all Docker containers
        """
        pass

    def test_get_docker_containers_metrics(self) -> None:
        """Test case for get_docker_containers_metrics

        GET Docker container uptimes, versions, statuses and logs for each container
        """
        pass


if __name__ == '__main__':
    unittest.main()
